@@ -18,6 +18,7 @@ extensions = [
         #'show_nodes',
         'sphinx.ext.autodoc',
         'sphinx.ext.autosectionlabel',
+        'sphinx.ext.autosummary',
         'sphinx.ext.intersphinx',
         'sphinx.ext.napoleon',
         'sphinx.ext.viewcode',
@@ -26,10 +27,22 @@ extensions = [
 intersphinx_mapping = {
         'python': ('https://docs.python.org/3', None),
         'pd': ('https://pandas.pydata.org/pandas-docs/stable/', None),
+        'mpl': ('https://matplotlib.org/', None),
 }
 default_role = 'any'
 add_function_parentheses = True
 pygments_style = 'sphinx'
+autosummary_generate = True
+rst_epilog = """\
+.. |well| replace:: `[well] <[well.A1]>`
+.. |block| replace:: `[block] <[block.WxH.A1]>`
+.. |row| replace:: `[row] <[row.A]>`
+.. |col| replace:: `[col] <[col.1]>`
+.. |irow| replace:: `[irow] <[irow.A]>`
+.. |icol| replace:: `[icol] <[icol.1]>`
+.. |plate| replace:: `[plate] <[plate.NAME]>`
+.. |expt| replace:: `[expt]`
+"""
 
 from sphinx_rtd_theme import get_html_theme_path
 html_theme = "sphinx_rtd_theme"
